==> kbib_0.6.1.orig.tar.gz: kbib-0.6.1/kbib/kbiblistviewitem.h <==
/***************************************************************************
                          kbiblistviewitem.h  -  description
                             -------------------
    begin                : Wed May 28 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach@dragon.thach.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBLISTVIEWITEM_H
#define KBIBLISTVIEWITEM_H

#include <qwidget.h>
#include <klistview.h>
#include <qstringlist.h>
#include "bibentrytable.h"
#include "bibentry.h"

//#include "entrydef.h"
/**
  *@author Thach Nguyen
  */

class KBibDoc;


class KBibListViewItem : public KListViewItem  {
//   Q_OBJECT
public: 
	KBibListViewItem(QListView *parent, KBibDoc *doc, BibEntry *item, QStringList displayFields, int numAuthorsDisplayed = 0);
	~KBibListViewItem();
  BibEntry* getBibEntry();
  /** No descriptions */
  void setBibEntry(BibEntry *);
  void updateItemContent(KBibDoc *doc, QStringList displayFields, int numAuthorsDisplayed = 0);

	
  
private:
  BibEntry * bibItem;

  
};

#endif

==> kbib_0.6.5.orig.tar.gz: kbib-0.6.5/kbib/kbiblistviewitem.h <==
/***************************************************************************
                          kbiblistviewitem.h  -  description
                             -------------------
    begin                : Wed May 28 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBLISTVIEWITEM_H
#define KBIBLISTVIEWITEM_H

#include <qwidget.h>
#include <klistview.h>
#include <qstringlist.h>
#include "bibentrytable.h"
#include "bibentry.h"

//#include "entrydef.h"
/**
  *@author Thach Nguyen
  */

class KBibDoc;


class KBibListViewItem : public KListViewItem  {
//   Q_OBJECT
public: 
	KBibListViewItem(QListView *parent, KBibDoc *doc, BibEntry *item, QStringList displayFields, int numAuthorsDisplayed = 0);
	~KBibListViewItem();
  BibEntry* getBibEntry();
  /** No descriptions */
  void setBibEntry(BibEntry *);
  void updateItemContent(KBibDoc *doc, QStringList displayFields, int numAuthorsDisplayed = 0);

	
  
private:
  BibEntry * bibItem;

  
};

#endif
